@@ -47,11 +47,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "7-Aug-23"
+#define SND_DATE "16-Oct-23"
 #ifndef SND_VERSION
-#define SND_VERSION "23.6"
+#define SND_VERSION "23.8"
 #endif
 #define SND_MAJOR_VERSION "23"
-#define SND_MINOR_VERSION "6"
+#define SND_MINOR_VERSION "8"
 
 #endif
